==> khttrack-0.10.tar.bz2: khttrack-0.10/khttrack/khttrackmirrorc.cpp <==
/***************************************************************************
                          khttrackmirrorc.cpp  -
                          Fonctions appeles par le moteur httrack (C++ Kde)
                             -------------------
    begin                : Wed Sep 4 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly@ifrance.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream> // cout
#include <klocale.h>  // i18n
#include <string.h>   //strcmp

#include "khttrackmirror.h"
#include "khttrackmirrorc.h"

KhttrackMirror *kMirrorViewGlobal;

int arretbrutal = 1;
char listurl[14][1024] = {"...","...","...","...","...","...","...","...","...","...","...","...","...","..."};
int  current ;

/** Fonctions appeles par le moteur httrack */
/*
    QPushButton* PushButton6;
    QLabel* LabelProgress;
    QLabel* TextLabel1;
    QCheckBox* actions;
    QGroupBox* GroupBox1;
    QLabel* TextLabel3;
    QLabel* TextLabel4;
    QLabel* TextLabel5;
    QLabel* TextLabel6;
    QLabel* Lwritten;
    QLabel* TextLabel15;
    QLabel* Llinks;
    QLabel* saved;
    QLabel* time;
    QLabel* rate;
    QLabel* TextLabel11;
    QLabel* links;
    QLabel* written;
    QLabel* files;
    QLabel* errors;
    QLabel* Lfiles;
    QFrame* Frame3;

*/
  void htinfo_link_detected(char *chaine)
{
    kMirrorViewGlobal->links->setText( chaine );
}
  void htinfo_mirror_info(char *chaine)
{
  kMirrorViewGlobal->LabelProgress->setText( i18n(chaine) );
}
  void htinfo_bytes_saved(char *chaine)
{
  kMirrorViewGlobal->saved->setText( chaine );
}
  void htinfo_time(char *chaine)
{
    kMirrorViewGlobal->time->setText( chaine );
    kMirrorViewGlobal->time->update();
}
  void htinfo_files_written(char *chaine)
{
   kMirrorViewGlobal->written->setText( chaine );
}
  void htinfo_transfer_rate(char *chaine)
{
    kMirrorViewGlobal->rate->setText( chaine );
}
  void htinfo_files_updated(char *chaine)
{
    kMirrorViewGlobal->files->setText( chaine );
}
  void htinfo_active_connections(char *chaine)
{
    kMirrorViewGlobal->TextLabel11->setText( chaine );
}
  void htinfo_errors(char *chaine)
{
    kMirrorViewGlobal->errors->setText( i18n(chaine) );
}
  void htinfo_state_url(char *chaine)
{

/*  if ( strcmp( chaine, listurl[0]) == 0)
  {
*/
    strcpy(listurl[0],chaine);
    kMirrorViewGlobal->url1->setText( listurl[0] );
    kMirrorViewGlobal->url2->setText( listurl[1] );
    kMirrorViewGlobal->url3->setText( listurl[2] );
    kMirrorViewGlobal->url4->setText( listurl[3] );
    kMirrorViewGlobal->url5->setText( listurl[4] );
    kMirrorViewGlobal->url6->setText( listurl[5] );
    kMirrorViewGlobal->url7->setText( listurl[6] );
    kMirrorViewGlobal->url8->setText( listurl[7] );
    kMirrorViewGlobal->url9->setText( listurl[8] );
    kMirrorViewGlobal->url10->setText( listurl[9] );
    kMirrorViewGlobal->url11->setText( listurl[10] );
    kMirrorViewGlobal->url12->setText( listurl[11] );
    kMirrorViewGlobal->url14->setText( listurl[12] );
    kMirrorViewGlobal->url15->setText( listurl[13] );


    strcpy(listurl[13],listurl[12]);
    strcpy(listurl[12],listurl[11]);
    strcpy(listurl[11],listurl[10]);
    strcpy(listurl[10],listurl[9]);
    strcpy(listurl[9],listurl[8]);
    strcpy(listurl[8],listurl[7]);
    strcpy(listurl[7],listurl[6]);
    strcpy(listurl[6],listurl[5]);
    strcpy(listurl[5],listurl[4]);
    strcpy(listurl[4],listurl[3]);
    strcpy(listurl[3],listurl[2]);
    strcpy(listurl[2],listurl[1]);
    strcpy(listurl[1],listurl[0]);

//  }

}
  void htinfo_state_url1(char *chaine)
{
    kMirrorViewGlobal->url1->setText( chaine );
}
  void htinfo_state_url2(char *chaine)
{
}
  void htinfo_state_url3(char *chaine)
{
}
  void htinfo_state_url4(char *chaine)
{
}
  void htinfo_state_url5(char *chaine)
{
}
  void htinfo_state_url6(char *chaine)
{
}
  void htinfo_state_url7(char *chaine)
{
}
  void htinfo_state_url8(char *chaine)
{
}
  void htinfo_state_url9(char *chaine)
{
}
  void htinfo_state_url10(char *chaine)
{
}
  void htinfo_state_url11(char *chaine)
{
}
  void htinfo_state_url12(char *chaine)
{
}
  void htinfo_state_url13(char *chaine)
{
}
  void htinfo_state_url14(char *chaine)
{
}

char* htquestion1(void)
{
    return kMirrorViewGlobal->Q1();
}

char* htquestion2(void)
{
    return kMirrorViewGlobal->Q2();
}

char* htquestion3(void)
{
    return kMirrorViewGlobal->Q3();
}

void htcommandend(void)
{
    kMirrorViewGlobal->endMirror();
}




/**/

==> khttrack-0.11.tar.bz2: khttrack-0.11/khttrack/khttrackmirrorc.cpp <==
/***************************************************************************
                          khttrackmirrorc.cpp  -
                          Fonctions appeles par le moteur httrack (C++ Kde)
                             -------------------
    begin                : Wed Sep 4 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly-devel@laposte.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream> // cout
#include <klocale.h>  // i18n
#include <string.h>   //strcmp

#include "khttrackmirror.h"
#include "khttrackmirrorc.h"

KhttrackMirror *kMirrorViewGlobal;

int arretbrutal = 1;
char listurl[14][1024] = {"...","...","...","...","...","...","...","...","...","...","...","...","...","..."};
int  current ;

/** Fonctions appeles par le moteur httrack */
/*
    QPushButton* PushButton6;
    QLabel* LabelProgress;
    QLabel* TextLabel1;
    QCheckBox* actions;
    QGroupBox* GroupBox1;
    QLabel* TextLabel3;
    QLabel* TextLabel4;
    QLabel* TextLabel5;
    QLabel* TextLabel6;
    QLabel* Lwritten;
    QLabel* TextLabel15;
    QLabel* Llinks;
    QLabel* saved;
    QLabel* time;
    QLabel* rate;
    QLabel* TextLabel11;
    QLabel* links;
    QLabel* written;
    QLabel* files;
    QLabel* errors;
    QLabel* Lfiles;
    QFrame* Frame3;

*/
  void htinfo_link_detected(char *chaine)
{
    kMirrorViewGlobal->links->setText( chaine );
}
  void htinfo_mirror_info(char *chaine)
{
  kMirrorViewGlobal->LabelProgress->setText( i18n(chaine) );
}
  void htinfo_bytes_saved(char *chaine)
{
  kMirrorViewGlobal->saved->setText( chaine );
}
  void htinfo_time(char *chaine)
{
    kMirrorViewGlobal->time->setText( chaine );
    kMirrorViewGlobal->time->update();
}
  void htinfo_files_written(char *chaine)
{
   kMirrorViewGlobal->written->setText( chaine );
}
  void htinfo_transfer_rate(char *chaine)
{
    kMirrorViewGlobal->rate->setText( chaine );
}
  void htinfo_files_updated(char *chaine)
{
    kMirrorViewGlobal->files->setText( chaine );
}
  void htinfo_active_connections(char *chaine)
{
    kMirrorViewGlobal->TextLabel11->setText( chaine );
}
  void htinfo_errors(char *chaine)
{
    kMirrorViewGlobal->errors->setText( i18n(chaine) );
}
  void htinfo_state_url(char *chaine)
{

/*  if ( strcmp( chaine, listurl[0]) == 0)
  {
*/
    strcpy(listurl[0],chaine);
    kMirrorViewGlobal->url1->setText( listurl[0] );
    kMirrorViewGlobal->url2->setText( listurl[1] );
    kMirrorViewGlobal->url3->setText( listurl[2] );
    kMirrorViewGlobal->url4->setText( listurl[3] );
    kMirrorViewGlobal->url5->setText( listurl[4] );
    kMirrorViewGlobal->url6->setText( listurl[5] );
    kMirrorViewGlobal->url7->setText( listurl[6] );
    kMirrorViewGlobal->url8->setText( listurl[7] );
    kMirrorViewGlobal->url9->setText( listurl[8] );
    kMirrorViewGlobal->url10->setText( listurl[9] );
    kMirrorViewGlobal->url11->setText( listurl[10] );
    kMirrorViewGlobal->url12->setText( listurl[11] );
    kMirrorViewGlobal->url14->setText( listurl[12] );
    kMirrorViewGlobal->url15->setText( listurl[13] );


    strcpy(listurl[13],listurl[12]);
    strcpy(listurl[12],listurl[11]);
    strcpy(listurl[11],listurl[10]);
    strcpy(listurl[10],listurl[9]);
    strcpy(listurl[9],listurl[8]);
    strcpy(listurl[8],listurl[7]);
    strcpy(listurl[7],listurl[6]);
    strcpy(listurl[6],listurl[5]);
    strcpy(listurl[5],listurl[4]);
    strcpy(listurl[4],listurl[3]);
    strcpy(listurl[3],listurl[2]);
    strcpy(listurl[2],listurl[1]);
    strcpy(listurl[1],listurl[0]);

//  }

}
  void htinfo_state_url1(char *chaine)
{
    kMirrorViewGlobal->url1->setText( chaine );
}
  void htinfo_state_url2(char *chaine)
{
}
  void htinfo_state_url3(char *chaine)
{
}
  void htinfo_state_url4(char *chaine)
{
}
  void htinfo_state_url5(char *chaine)
{
}
  void htinfo_state_url6(char *chaine)
{
}
  void htinfo_state_url7(char *chaine)
{
}
  void htinfo_state_url8(char *chaine)
{
}
  void htinfo_state_url9(char *chaine)
{
}
  void htinfo_state_url10(char *chaine)
{
}
  void htinfo_state_url11(char *chaine)
{
}
  void htinfo_state_url12(char *chaine)
{
}
  void htinfo_state_url13(char *chaine)
{
}
  void htinfo_state_url14(char *chaine)
{
}

char* htquestion1(void)
{
    return kMirrorViewGlobal->Q1();
}

char* htquestion2(void)
{
    return kMirrorViewGlobal->Q2();
}

char* htquestion3(void)
{
    return kMirrorViewGlobal->Q3();
}

void htcommandend(void)
{
    kMirrorViewGlobal->endMirror();
}




/**/
